@@ -279,90 +279,6 @@ class NlpClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
-    def DescribeEntity(self, request):
-        """此接口正在维护升级，后续上线另行通知。
-
-        :param request: Request instance for DescribeEntity.
-        :type request: :class:`tencentcloud.nlp.v20190408.models.DescribeEntityRequest`
-        :rtype: :class:`tencentcloud.nlp.v20190408.models.DescribeEntityResponse`
-
-        """
-        try:
-            params = request._serialize()
-            body = self.call("DescribeEntity", params)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeEntityResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
-    def DescribeRelation(self, request):
-        """此接口正在维护升级，后续上线另行通知。
-
-        :param request: Request instance for DescribeRelation.
-        :type request: :class:`tencentcloud.nlp.v20190408.models.DescribeRelationRequest`
-        :rtype: :class:`tencentcloud.nlp.v20190408.models.DescribeRelationResponse`
-
-        """
-        try:
-            params = request._serialize()
-            body = self.call("DescribeRelation", params)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeRelationResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
-    def DescribeTriple(self, request):
-        """此接口正在维护升级，后续上线另行通知。
-
-        :param request: Request instance for DescribeTriple.
-        :type request: :class:`tencentcloud.nlp.v20190408.models.DescribeTripleRequest`
-        :rtype: :class:`tencentcloud.nlp.v20190408.models.DescribeTripleResponse`
-
-        """
-        try:
-            params = request._serialize()
-            body = self.call("DescribeTriple", params)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeTripleResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
     def DescribeWordItems(self, request):
         """依据自定义词库的ID，查询对应的词条信息。
 
@@ -580,8 +496,6 @@ class NlpClient(AbstractClient):
 
         - 通用领域分类体系，二级分类，包括14个分类类目，分别是汽车、科技、健康、体育、旅行、教育、职业、文化、房产、娱乐、女性、奥运、财经以及其他，适用于通用的场景。
 
-        - 新闻领域分类体系，五级分类，包括35个一级分类类目，228个二级分类，493个三级分类，204个四级分类，40个五级分类（详细请见附录->文本分类映射表），已应用于腾讯新闻的文章分类。
-
         :param request: Request instance for TextClassification.
         :type request: :class:`tencentcloud.nlp.v20190408.models.TextClassificationRequest`
         :rtype: :class:`tencentcloud.nlp.v20190408.models.TextClassificationResponse`
@@ -637,6 +551,36 @@ class NlpClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def TextCorrectionPro(self, request):
+        """提供对中文文本的自动纠错功能，能够识别输入文本中的错误片段，定位错误并给出正确的文本结果；支持长度不超过128字符（含标点符号）的长文本纠错。
+
+        此功能是基于千亿级大规模互联网语料和LSTM、BERT等深度神经网络模型进行训练，并持续迭代更新，以保证效果不断提升，是搜索引擎、语音识别、内容审核等功能更好运行的基础之一。
+
+        :param request: Request instance for TextCorrectionPro.
+        :type request: :class:`tencentcloud.nlp.v20190408.models.TextCorrectionProRequest`
+        :rtype: :class:`tencentcloud.nlp.v20190408.models.TextCorrectionProResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("TextCorrectionPro", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.TextCorrectionProResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def TextSimilarity(self, request):
         """句子相似度接口能够基于深度学习技术来计算一个源句子和多个目标句子的相似度，相似度分值越大的两个句子在语义上越相似。目前仅支持短文本（不超过500字符）的相似度计算，长文本的相似度计算也即将推出。
 
